import { Web3Provider } from "@ethersproject/providers";
import { MiniRpcProvider } from "./minirpc.js";
var RpcConnector = /** @class */ (function () {
    function RpcConnector(args) {
        var _this = this;
        /* c8 ignore next */
        var urls = args.urls, _a = args.batchInterval, batchInterval = _a === void 0 ? 50 : _a;
        this._chainEndpoints = urls;
        var miniRpcProviders = Object.keys(urls).reduce(function (acc, chainId) {
            var cid = Number(chainId);
            acc[cid] = _this._newProvider(cid, urls[cid], batchInterval);
            return acc;
        }, {});
        var web3Providers = Object.keys(miniRpcProviders).reduce(function (acc, chainId) {
            var cid = Number(chainId);
            acc[cid] = new Web3Provider(miniRpcProviders[cid]);
            return acc;
        }, {});
        this._providers = miniRpcProviders;
        this._web3Providers = web3Providers;
    }
    RpcConnector.prototype.provider = function (chainId) {
        return this._web3Providers[chainId];
    };
    /**
     * @internal
     */
    RpcConnector.prototype.setProviderConfig = function (chainId, endpoint, batchInterval) {
        if (batchInterval === void 0) { batchInterval = 50; }
        var provider = this._newProvider(chainId, endpoint, batchInterval);
        delete this._chainEndpoints[chainId];
        delete this._providers[chainId];
        delete this._web3Providers[chainId];
        this._chainEndpoints[chainId] = endpoint;
        this._providers[chainId] = provider;
        this._web3Providers[chainId] = new Web3Provider(provider);
    };
    RpcConnector.prototype._newProvider = function (chainId, endpoint, batchInterval) {
        return new MiniRpcProvider(chainId, endpoint, batchInterval);
    };
    return RpcConnector;
}());
export { RpcConnector };
